@@ -34,15 +34,13 @@
 #include <libxml/debugXML.h>
 #include <libxml/HTMLtree.h>
 #include <libxml/xmlIO.h>
-#ifdef LIBXML_DOCB_ENABLED
-#include <libxml/DOCBparser.h>
-#endif
 #ifdef LIBXML_XINCLUDE_ENABLED
 #include <libxml/xinclude.h>
 #endif
 #ifdef LIBXML_CATALOG_ENABLED
 #include <libxml/catalog.h>
 #endif
+#include <libxml/parser.h>
 #include <libxml/parserInternals.h>
 #include <libxml/uri.h>
 
@@ -94,12 +92,10 @@ static int timing = 0;
 static int dumpextensions = 0;
 static int novalid = 0;
 static int noout = 0;
-#ifdef LIBXML_DOCB_ENABLED
-static int docbook = 0;
-#endif
 #ifdef LIBXML_HTML_ENABLED
 static int html = 0;
 #endif
+static int load_trace = 0;
 #ifdef LIBXML_XINCLUDE_ENABLED
 static int xinclude = 0;
 #endif
@@ -108,6 +104,9 @@ static int profile = 0;
 #define MAX_PARAMETERS 64
 #define MAX_PATHS 64
 
+#if LIBXML_VERSION >= 20600
+static int options = XSLT_PARSE_OPTIONS;
+#endif
 static const char *params[MAX_PARAMETERS + 1];
 static int nbparams = 0;
 static xmlChar *strparams[MAX_PARAMETERS + 1];
@@ -177,6 +176,13 @@ xsltprocExternalEntityLoader(const char *URL, const char *ID,
 	if (ret != NULL) {
 	    if (warning != NULL)
 		ctxt->sax->warning = warning;
+	    if (load_trace) {
+		fprintf \
+			(stderr,
+			 "Loaded URL=\"%s\" ID=\"%s\"\n",
+			 URL ? URL : "(null)",
+			 ID ? ID : "(null)");
+	    }
 	    return(ret);
 	}
     }
@@ -188,12 +194,20 @@ xsltprocExternalEntityLoader(const char *URL, const char *ID,
 	newURL = xmlStrcat(newURL, (const xmlChar *) lastsegment);
 	if (newURL != NULL) {
 	    ret = defaultEntityLoader((const char *)newURL, ID, ctxt);
-	    xmlFree(newURL);
 	    if (ret != NULL) {
 		if (warning != NULL)
 		    ctxt->sax->warning = warning;
+		if (load_trace) {
+		    fprintf \
+		    	(stderr,
+		    	 "Loaded URL=\"%s\" ID=\"%s\"\n",
+			 newURL,
+		    	 ID ? ID : "(null)");
+		}
+		xmlFree(newURL);
 		return(ret);
 	    }
+	    xmlFree(newURL);
 	}
     }
     if (warning != NULL) {
@@ -360,7 +374,11 @@ xsltProcess(xmlDocPtr doc, xsltStylesheetPtr cur, const char *filename) {
     if (xinclude) {
 	if (timing)
 	    startTimer();
+#if LIBXML_VERSION >= 20603
+	xmlXIncludeProcessFlags(doc, XSLT_PARSE_OPTIONS);
+#else
 	xmlXIncludeProcess(doc);
+#endif
 	if (timing) {
 	    endTimer("XInclude processing %s", filename);
 	}
@@ -376,17 +394,21 @@ xsltProcess(xmlDocPtr doc, xsltStylesheetPtr cur, const char *filename) {
 		res = xsltApplyStylesheet(cur, doc, params);
 		xmlFreeDoc(res);
 		xmlFreeDoc(doc);
+#if LIBXML_VERSION >= 20600
+#ifdef LIBXML_HTML_ENABLED
+		if (html)
+		    doc = htmlReadFile(filename, NULL, options);
+		else
+#endif
+		    doc = xmlReadFile(filename, NULL, options);
+#else
 #ifdef LIBXML_HTML_ENABLED
 		if (html)
 		    doc = htmlParseFile(filename, NULL);
 		else
-#endif
-#ifdef LIBXML_DOCB_ENABLED
-		if (docbook)
-		    doc = docbParseFile(filename, NULL);
-		else
 #endif
 		    doc = xmlParseFile(filename);
+#endif
 	    }
 	}
 	ctxt = xsltNewTransformContext(cur, doc);
@@ -452,16 +474,15 @@ xsltProcess(xmlDocPtr doc, xsltStylesheetPtr cur, const char *filename) {
 
 	xmlFreeDoc(res);
     } else {
-	int ret;
 
 	ctxt = xsltNewTransformContext(cur, doc);
 	if (ctxt == NULL)
 	    return;
 	if (profile) {
-	    ret = xsltRunStylesheetUser(cur, doc, params, output,
+	    xsltRunStylesheetUser(cur, doc, params, output,
 		                        NULL, NULL, stderr, ctxt);
 	} else {
-	    ret = xsltRunStylesheetUser(cur, doc, params, output,
+	    xsltRunStylesheetUser(cur, doc, params, output,
 		                        NULL, NULL, NULL, ctxt);
 	}
 	if (ctxt->state == XSLT_STATE_ERROR)
@@ -481,16 +502,18 @@ static void usage(const char *name) {
     printf("\t--output file or -o file: save to a given file\n");
     printf("\t--timing: display the time used\n");
     printf("\t--repeat: run the transformation 20 times\n");
+#ifdef LIBXML_DEBUG_ENABLED
     printf("\t--debug: dump the tree of the result instead\n");
+#endif
     printf("\t--dumpextensions: dump the registered extension elements and functions to stdout\n");
     printf("\t--novalid skip the Dtd loading phase\n");
     printf("\t--noout: do not dump the result\n");
     printf("\t--maxdepth val : increase the maximum depth\n");
+#if LIBXML_VERSION >= 20600
+    printf("\t--maxparserdepth val : increase the maximum parser depth\n");
+#endif
 #ifdef LIBXML_HTML_ENABLED
     printf("\t--html: the input document is(are) an HTML file(s)\n");
-#endif
-#ifdef LIBXML_DOCB_ENABLED
-    printf("\t--docbook: the input document is SGML docbook\n");
 #endif
     printf("\t--param name value : pass a (parameter,value) pair\n");
     printf("\t       value is an UTF8 XPath expression.\n");
@@ -510,6 +533,7 @@ static void usage(const char *name) {
 #ifdef LIBXML_XINCLUDE_ENABLED
     printf("\t--xinclude : do XInclude processing on document intput\n");
 #endif
+    printf("\t--load-trace : print trace of all external entites loaded\n");
     printf("\t--profile or --norman : dump profiling informations \n");
     printf("\nProject libxslt home page: http://xmlsoft.org/XSLT/\n");
     printf("To report bugs and get help: http://xmlsoft.org/XSLT/bugs.html\n");
@@ -532,7 +556,6 @@ main(int argc, char **argv)
 
     LIBXML_TEST_VERSION
 
-    xmlLineNumbersDefault(1);
     sec = xsltNewSecurityPrefs();
     xsltSetDefaultSecurityPrefs(sec);
     defaultEntityLoader = xmlGetExternalEntityLoader();
@@ -586,11 +609,6 @@ main(int argc, char **argv)
         } else if ((!strcmp(argv[i], "-noout")) ||
                    (!strcmp(argv[i], "--noout"))) {
             noout++;
-#ifdef LIBXML_DOCB_ENABLED
-        } else if ((!strcmp(argv[i], "-docbook")) ||
-                   (!strcmp(argv[i], "--docbook"))) {
-            docbook++;
-#endif
 #ifdef LIBXML_HTML_ENABLED
         } else if ((!strcmp(argv[i], "-html")) ||
                    (!strcmp(argv[i], "--html"))) {
@@ -648,6 +666,9 @@ main(int argc, char **argv)
             xinclude++;
             xsltSetXIncludeDefault(1);
 #endif
+        } else if ((!strcmp(argv[i], "-load-trace")) ||
+                   (!strcmp(argv[i], "--load-trace"))) {
+            load_trace++;
         } else if ((!strcmp(argv[i], "-param")) ||
                    (!strcmp(argv[i], "--param"))) {
             i++;
@@ -661,12 +682,10 @@ main(int argc, char **argv)
                    (!strcmp(argv[i], "--stringparam"))) {
 	    const xmlChar *string;
 	    xmlChar *value;
-	    int len;
 
             i++;
             params[nbparams++] = argv[i++];
 	    string = (const xmlChar *) argv[i];
-	    len = xmlStrlen(string);
 	    if (xmlStrchr(string, '"')) {
 		if (xmlStrchr(string, '\'')) {
 		    fprintf(stderr,
@@ -697,6 +716,17 @@ main(int argc, char **argv)
                 if (value > 0)
                     xsltMaxDepth = value;
             }
+#if LIBXML_VERSION >= 20600
+        } else if ((!strcmp(argv[i], "-maxparserdepth")) ||
+                   (!strcmp(argv[i], "--maxparserdepth"))) {
+            int value;
+
+            i++;
+            if (sscanf(argv[i], "%d", &value) == 1) {
+                if (value > 0)
+                    xmlParserMaxDepth = value;
+            }
+#endif
         } else if ((!strcmp(argv[i],"-dumpextensions"))||
 			(!strcmp(argv[i],"--dumpextensions"))) {
 		dumpextensions++;
@@ -709,16 +739,17 @@ main(int argc, char **argv)
     }
     params[nbparams] = NULL;
 
+#if LIBXML_VERSION < 20600
+    /*
+     * The old parser interfaces uses the global variables
+     */
     if (novalid == 0)
         xmlLoadExtDtdDefaultValue = XML_DETECT_IDS | XML_COMPLETE_ATTRS;
     else
         xmlLoadExtDtdDefaultValue = 0;
-
-
-    /*
-     * Replace entities with their content.
-     */
     xmlSubstituteEntitiesDefault(1);
+    xmlLineNumbersDefault(1);
+#endif
 
     /*
      * Register the EXSLT extensions and the test module
@@ -734,6 +765,12 @@ main(int argc, char **argv)
             (!strcmp(argv[i], "--maxdepth"))) {
             i++;
             continue;
+#if LIBXML_VERSION >= 20600
+        } else if ((!strcmp(argv[i], "-maxparserdepth")) ||
+            (!strcmp(argv[i], "--maxparserdepth"))) {
+            i++;
+            continue;
+#endif
         } else if ((!strcmp(argv[i], "-o")) ||
                    (!strcmp(argv[i], "-output")) ||
                    (!strcmp(argv[i], "--output"))) {
@@ -760,7 +797,11 @@ main(int argc, char **argv)
         if ((argv[i][0] != '-') || (strcmp(argv[i], "-") == 0)) {
             if (timing)
                 startTimer();
+#if LIBXML_VERSION >= 20600
+	    style = xmlReadFile((const char *) argv[i], NULL, options);
+#else
 	    style = xmlParseFile((const char *) argv[i]);
+#endif
             if (timing) 
 		endTimer("Parsing stylesheet %s", argv[i]);
 	    if (style == NULL) {
@@ -794,28 +835,35 @@ main(int argc, char **argv)
         }
     }
 
+#if LIBXML_VERSION < 20600
     /*
+     * The old parser interfaces uses the global variables
      * disable CDATA from being built in the document tree
      */
     xmlDefaultSAXHandlerInit();
     xmlDefaultSAXHandler.cdataBlock = NULL;
+#endif
 
     if ((cur != NULL) && (cur->errors == 0)) {
         for (; i < argc; i++) {
 	    doc = NULL;
             if (timing)
                 startTimer();
+#if LIBXML_VERSION >= 20600
+#ifdef LIBXML_HTML_ENABLED
+            if (html)
+                doc = htmlReadFile(argv[i], NULL, options);
+            else
+#endif
+                doc = xmlReadFile(argv[i], NULL, options);
+#else
 #ifdef LIBXML_HTML_ENABLED
             if (html)
                 doc = htmlParseFile(argv[i], NULL);
             else
-#endif
-#ifdef LIBXML_DOCB_ENABLED
-            if (docbook)
-                doc = docbParseFile(argv[i], NULL);
-            else
 #endif
                 doc = xmlParseFile(argv[i]);
+#endif
             if (doc == NULL) {
                 fprintf(stderr, "unable to parse %s\n", argv[i]);
 		errorno = 6;
